import * as react_jsx_runtime from 'react/jsx-runtime';
import * as React$1 from 'react';

/**
 * All supported `LiveRegion` roles.
 *
 * @enum {String}
 * @see https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques#Live_Region_Roles
 */
declare const ROLES: {
    /**
     * A message with important, and usually time-sensitive
     * information.
     *
     * Default politeness is `null` (does not add the
     * `aria-live` attribute).
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/Alert_Role
     * @see https://www.w3.org/TR/2009/WD-wai-aria-20091215/roles#alert
     */
    ALERT: string;
    /**
     * A type of dialog that contains an alert message, where
     * initial focus goes to the dialog or an element
     * within it.
     *
     * Authors SHOULD use aria-describedby on an alertdialog
     * to point to the alert message element in the
     * dialog.
     *
     * Default politeness is `null` (does not add the
     * `aria-live` attribute).
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_alertdialog_role
     * @see https://www.w3.org/TR/2009/WD-wai-aria-20091215/roles#alertdialog
     */
    ALERTDIALOG: string;
    /**
     * A type of live region where new information is added in
     * meaningful order and old information may
     * disappear.
     *
     * Default politeness is `"polite"`.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_log_role
     * @see https://www.w3.org/TR/2009/WD-wai-aria-20091215/roles#log
     */
    LOG: string;
    /**
     * A type of live region where non-essential information
     * changes frequently. The primary difference
     * between a marquee and a log is that logs usually have
     * a meaningful order or sequence of important
     * content changes.
     *
     * Default politeness is `null` (does not add the
     * `aria-live` attribute).
     */
    MARQUEE: string;
    /**
     * An element that displays the progress status for tasks
     * that take a long time.
     *
     * Default politeness is `null` (does not add the
     * `aria-live` attribute).
     *
     * @see https://www.w3.org/TR/2009/WD-wai-aria-20091215/roles#progressbar
     */
    PROGRESSBAR: string;
    /**
     * A container whose content is advisory information for
     * the user but is not important enough to justify
     * an alert.
     *
     * Default politeness is `"polite"`.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_status_role
     * @see https://www.w3.org/TR/2009/WD-wai-aria-20091215/roles#status
     */
    STATUS: string;
    /**
     * A numerical counter which indicates an amount of
     * elapsed time from a start point, or the time remaining
     * until an end point.
     *
     * Default politeness is `"assertive"`.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/ARIA_timer_role
     * @see https://www.w3.org/TR/2009/WD-wai-aria-20091215/roles#timer
     */
    TIMER: string;
};

type LiveRegionProps = {
	/**
	 * The content to be announced by the live region.
	 */
	children: React.ReactNode;
	/**
	 * The number of milliseconds to wait before announcing the content.
	 */
	announcementDelay?: number;
	/**
	 * The `className` to apply to the live region.
	 */
	className?: string;
	/**
	 * The number of milliseconds to wait before clearing the announcement.
	 */
	clearAnnouncementDelay?: number;
	/**
	 * A callback to be invoked when the announcement is cleared.
	 */
	onAnnouncementClear?: () => void;
	/**
	 * The `aria-live` politeness level to apply to the live region.
	 */
	politeness?: "polite" | "assertive" | "off" | null | undefined;
	/**
	 * The `role` to apply to the live region.
	 */
	role?: typeof ROLES.ALERT | "status" | null | undefined;
	/**
	 * Whether or not the live region should be visible.
	 */
	visible?: boolean;
};

/**
 * The `LiveRegion` component abstracts the logic for
 * rendering live region content that consistently announces
 * across assistive technologies (e.g. JAWS, VoiceOver,
 * NVDA).
 */
declare function LiveRegion({ children, className, politeness: politenessProp, role, announcementDelay, clearAnnouncementDelay, onAnnouncementClear, visible, ...otherProps }: LiveRegionProps): react_jsx_runtime.JSX.Element;

interface ModalOptions {
	initialOpen?: boolean;
	onOpenChange?: (open: boolean) => void;
	open?: boolean;
}

declare function Modal({ children, ...options }: {
    children: React$1.ReactNode;
} & ModalOptions): react_jsx_runtime.JSX.Element;
type overlayBackgroundProps = {
    overlayBackground?: string;
};
declare const ModalContent: React$1.ForwardRefExoticComponent<Omit<React$1.HTMLProps<HTMLDivElement> & overlayBackgroundProps, "ref"> & React$1.RefAttributes<HTMLDivElement>>;
declare const ModalHeading: React$1.ForwardRefExoticComponent<Omit<React$1.HTMLProps<HTMLHeadingElement>, "ref"> & React$1.RefAttributes<HTMLHeadingElement>>;
declare const ModalDescription: React$1.ForwardRefExoticComponent<Omit<React$1.HTMLProps<HTMLParagraphElement>, "ref"> & React$1.RefAttributes<HTMLParagraphElement>>;
declare const ModalClose: React$1.ForwardRefExoticComponent<{
    trigger: React$1.ReactElement;
    className?: string;
} & React$1.RefAttributes<HTMLButtonElement>>;

type SpacingType =
	| undefined
	| string
	| number
	| {
			b?: number;
			l?: number;
			r?: number;
			t?: number;
	  };

/**
 * Custom spacing for a component.
 * @example
 * ```tsx
 * <Button spacing={{ b: 2, l: 1, r: 1, t: 2 }}>Hello World</Button>
 * <Button spacing="2">Hello World</Button>
 * <Button spacing={2}>Hello World</Button>
 * ```
 */
type SpacingProps = {
	spacing?: SpacingType;
};

type SvgIconProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * The default viewBox to use.
	 */
	defaultViewBox: string;
	/**
	 * The title to use for the icon. Each icon has a default title,
	 * but it can be overridden with this prop.
	 */
	title: string;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	defaultClassName?: string;
	/**
	 * Update the "fill" property of the SVG.
	 * @default "currentColor"
	 */
	fill?: string;
	/**
	 * Whether or not the icon is semantic (visual and
	 * announced to assistive technologies).
	 * @default false
	 */
	semantic?: boolean;
	/**
	 * The viewBox to use. If not provided, the default viewBox will be used.
	 */
	viewBox?: string;
} & SpacingProps;

declare const SvgIcon: ({ children, fill, viewBox, className, defaultViewBox, defaultClassName, spacing, title, semantic, ...rest }: SvgIconProps) => react_jsx_runtime.JSX.Element;

export { LiveRegion, Modal, ModalClose, ModalContent, ModalDescription, ModalHeading, SvgIcon };
